@@ -113,7 +113,7 @@ our @params = (
         'default'    => 'mysql',
         'gettext_id' => 'Type of the database',
         'gettext_comment' =>
-            'Possible types are "MySQL", "PostgreSQL", "Oracle", "Sybase" and "SQLite".',
+            'Possible types are "MySQL", "PostgreSQL", "Oracle" and "SQLite".',
         'file' => 'sympa.conf',
         'edit' => '1',
     },
@@ -483,7 +483,7 @@ our @params = (
         'default'    => '-oi -odi -oem',
         'gettext_id' => 'Command line parameters passed to sendmail',
         'gettext_comment' =>
-            "Note that \"-f\", \"-N\" and \"-V\" options and recipient addresses need not included, because they will be included by Sympa.",
+            "Note that \"-f\", \"-N\" and \"-V\" options and recipient addresses should not be included, because they will be included by Sympa.",
     },
     {   'name'       => 'log_smtp',
         'gettext_id' => 'Log invocation of sendmail',
@@ -568,17 +568,18 @@ our @params = (
         'vhost'      => '1',
         'edit'       => '1',
         'gettext_comment' =>
-            'Restrict list ownership to addresses in the specified domains. This can be used to reserve list ownership to a group of trusted users from a set of domains associated with an organization, while allowing editors and subscribers from the Internet at large.',
-        'default'    => undef,
+            'Restrict list ownership to addresses in the specified domains. This can be used to reserve list ownership to a group of trusted users from a set of domains associated with an organization, while allowing moderators and subscribers from the Internet at large.',
+        'default' => undef,
     },
-    {   'name'       => 'owner_domain_min',
-        'sample'     => '1',
-        'gettext_id' => 'Minimum number of owners for each list that must match owner_domain restriction',
-        'file'       => 'sympa.conf',
-        'default'    => '0',
-        'optional'   => '1',
-        'vhost'      => '1',
-        'edit'       => '1',
+    {   'name'   => 'owner_domain_min',
+        'sample' => '1',
+        'gettext_id' =>
+            'Minimum number of owners for each list that must match owner_domain restriction',
+        'file'     => 'sympa.conf',
+        'default'  => '0',
+        'optional' => '1',
+        'vhost'    => '1',
+        'edit'     => '1',
         'gettext_comment' =>
             'Minimum number of owners for each list must satisfy the owner_domain restriction. The default of zero (0) means *all* list owners must match. Setting to 1 requires only one list owner to match owner_domain; all other owners can be from any domain. This setting can be used to ensure that there is always at least one known contact point for any mailing list.',
     },
@@ -603,7 +604,7 @@ our @params = (
     {   'name'       => 'ignore_x_no_archive_header_feature',
         'gettext_id' => 'Ignore "X-no-archive:" header field',
         'gettext_comment' =>
-            'Sympa\'s default behavior is to skip archiving of incoming messages that have an "X-no-archive:" header field set. This parameter allows to change this behavior.',
+            'Sympa\'s default behavior is to skip archiving of incoming messages that have an "X-no-archive:" header field set. This parameter allows one to change this behavior.',
         'default' => 'off',
         'sample'  => 'on',
     },
@@ -1238,6 +1239,7 @@ our @params = (
         'sample'     => '123456789',
         'gettext_id' => 'Secret string for generating unique keys',
         'file'       => 'sympa.conf',
+        'obfuscated' => '1',
         'gettext_comment' =>
             "This allows generated authentication keys to differ from a site to another. It is also used for encryption of user passwords stored in the database. The presence of this string is one reason why access to \"sympa.conf\" needs to be restricted to the \"sympa\" user.\nNote that changing this parameter will break all HTTP cookies stored in users' browsers, as well as all user passwords and lists X509 private keys. To prevent a catastrophe, Sympa refuses to start if this \"cookie\" parameter was changed.",
         'optional' => '1',
@@ -1248,10 +1250,11 @@ our @params = (
     # Basic configuration
 
     {   'name'       => 'wwsympa_url',
-        'sample'     => 'http://web.example.org/sympa',
+        'sample'     => 'https://web.example.org/sympa',
         'gettext_id' => 'URL prefix of web interface',
         'vhost'      => '1',
         'file'       => 'sympa.conf',
+        'optional'   => '1',
         'edit'       => '1',
         'gettext_comment' =>
             'This is used to construct URLs of web interface.',
@@ -1331,7 +1334,7 @@ our @params = (
         'gettext_id' => 'Colors for web interface',
         'gettext_comment' =>
             'Colors are used in style sheet (CSS). They may be changed using web interface by listmasters.',
-        'default' => '#F7F7F7',    # very light grey use in tables,
+        'default' => '#f7f7f7',    # very light grey use in tables,
         'vhost'   => '1',
         'db'      => 'db_first',
     },
@@ -1341,12 +1344,12 @@ our @params = (
         'db'      => 'db_first',
     },
     {   'name'    => 'color_2',
-        'default' => '#004B94',    # font color,
+        'default' => '#004b94',    # font color,
         'vhost'   => '1',
         'db'      => 'db_first',
     },
     {   'name'    => 'color_3',
-        'default' => '#5E5E5E',    # top boxe and footer box bacground color,
+        'default' => '#5e5e5e',    # top boxe and footer box bacground color,
         'vhost'   => '1',
         'db'      => 'db_first',
     },
@@ -1356,7 +1359,7 @@ our @params = (
         'db'      => 'db_first',
     },
     {   'name'    => 'color_5',
-        'default' => '#0090E9',
+        'default' => '#0090e9',
         'vhost'   => '1',
         'db'      => 'db_first',
     },
@@ -1366,7 +1369,7 @@ our @params = (
         'db'      => 'db_first',
     },
     {   'name'    => 'color_7',
-        'default' => '#fff',       # errorbackground color,
+        'default' => '#ffffff',    # errorbackground color,
         'vhost'   => '1',
         'db'      => 'db_first',
     },
@@ -1391,17 +1394,17 @@ our @params = (
         'db'      => 'db_first',
     },
     {   'name'    => 'color_12',
-        'default' => '#FFE7E7',
+        'default' => '#ffe7e7',
         'vhost'   => '1',
         'db'      => 'db_first',
     },
     {   'name'    => 'color_13',
-        'default' => '#f48A7b',    # input backgound  | transparent,
+        'default' => '#f48a7b',    # input backgound  | transparent,
         'vhost'   => '1',
         'db'      => 'db_first',
     },
     {   'name'    => 'color_14',
-        'default' => '#ff9',
+        'default' => '#ffff99',
         'vhost'   => '1',
         'db'      => 'db_first',
     },
@@ -1412,7 +1415,7 @@ our @params = (
     },
     {   'name'       => 'dark_color',
         'gettext_id' => 'Colors for web interface, obsoleted',
-        'default'    => 'silver',
+        'default'    => '#c0c0c0',                               # 'silver'
         'vhost'      => '1',
         'db'         => 'db_first',
     },
@@ -1437,7 +1440,7 @@ our @params = (
         'db'      => 'db_first',
     },
     {   'name'    => 'selected_color',
-        'default' => 'silver',
+        'default' => '#c0c0c0',          # 'silver'
         'vhost'   => '1',
         'db'      => 'db_first',
     },
@@ -1608,12 +1611,6 @@ our @params = (
     },
     ##{ html_editor_hide: not yet implemented. },
     ##{ html_editor_show: not yet implemented. },
-    {   'name'       => 'htmlarea_url',    #FIXME:Let's deprecate it.
-        'gettext_id' => '',
-        'default'    => undef,
-        'file'       => 'wwsympa.conf',
-        'optional'   => 1,
-    },
 
     # Password
 
@@ -1717,7 +1714,7 @@ our @params = (
         'optional'   => '1',
         'gettext_id' => 'Script to report spam',
         'gettext_comment' =>
-            'If set, when a list editor report undetected spams for list moderation, this external script is invoked and the message is injected into standard input of the script.',
+            'If set, when a list moderator report undetected spams for list moderation, this external script is invoked and the message is injected into standard input of the script.',
         'vhost' => '1',
         'file'  => 'sympa.conf',
     },
@@ -1760,9 +1757,10 @@ our @params = (
         'gettext_id' => 'Password used to crypt lists private keys',
         'gettext_comment' =>
             'If not defined, Sympa assumes that list private keys are not encrypted.',
-        'file'     => 'sympa.conf',
-        'edit'     => '1',
-        'optional' => '1',
+        'file'       => 'sympa.conf',
+        'edit'       => '1',
+        'obfuscated' => '1',
+        'optional'   => '1',
     },
     # Not yet implemented
     #{   'name'    => 'crl_dir',
@@ -1777,7 +1775,7 @@ our @params = (
 
     {   'gettext_id' => 'Data sources setup',
         'gettext_comment' =>
-            'Including subscribers, owners and editors from datasources. Appropriate database driver (DBD) modules are required: DBD-CSV, DBD-mysql, DBD-ODBC, DBD-Oracle, DBD-Pg, DBD-SQLite, DBD-Sybase and/or Net-LDAP. And also, if secure connection (LDAPS) to LDAP server is required: IO-Socket-SSL.',
+            'Including subscribers, owners and moderators from data sources. Appropriate database driver (DBD) modules are required: DBD-CSV, DBD-mysql, DBD-ODBC, DBD-Oracle, DBD-Pg, DBD-SQLite and/or Net-LDAP. And also, if secure connection (LDAPS) to LDAP server is required: IO-Socket-SSL.',
     },
 
     {   'name'       => 'default_sql_fetch_timeout',
@@ -2058,7 +2056,7 @@ our @params = (
         'file'    => 'sympa.conf',
         'default' => '300',
     },
-    {   'name'    => 'voot_feature', # Not implemented yet.
+    {   'name'    => 'voot_feature',             # Not implemented yet.
         'default' => 'off',
         'file'    => 'sympa.conf',
     },
@@ -2075,6 +2073,12 @@ our @params = (
         'gettext_comment' =>
             'Is FastCGI module for HTTP server installed? This module provides a much faster web interface.',
     },
+    {   'name'       => 'htmlarea_url',          # Deprecated on 6.2.36
+        'gettext_id' => '',
+        'default'    => undef,
+        'file'       => 'wwsympa.conf',
+        'optional'   => 1,
+    },
 
 ## Not implemented yet.
 ##    {
