@@ -31,6 +31,7 @@ use strict;
 use warnings;
 
 use Sympa::Language;
+use Sympa::Robot;
 
 my $language = Sympa::Language->instance;
 
@@ -188,7 +189,7 @@ my %list_option = (
         {'gettext_id' => 'authenticated by S/MIME signature'},
     'dkim_authenticated_messages' =>
         {'gettext_id' => 'authenticated by DKIM signature'},
-    'editor_validated_messages' => {'gettext_id' => 'approved by editor'},
+    'editor_validated_messages' => {'gettext_id' => 'approved by moderator'},
     'any'                       => {'gettext_id' => 'any messages'},
 
     # archive.period
@@ -294,7 +295,8 @@ sub get_option_description {
         if ($type eq 'listtopic') {
             $title = Sympa::Robot::topic_get_title($robot_id, $option);
         } else {
-            $title = [Sympa::Robot::topic_get_title($robot_id, $option)]->[-1];
+            $title =
+                [Sympa::Robot::topic_get_title($robot_id, $option)]->[-1];
         }
     } elsif ($type eq 'password') {
         return '*' x length($option);    # return
@@ -306,7 +308,7 @@ sub get_option_description {
             'reception'  => \%reception_mode,
             'visibility' => \%visibility_mode,
             'status'     => \%list_status,
-            }->{$type}
+        }->{$type}
             || \%list_option;
         my $t = $map->{$option} || {};
         if ($t->{gettext_id}) {
