@@ -4,8 +4,8 @@
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
-# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
-# directory of this distribution and at
+# Copyright 2017, 2018 The Sympa Community. See the AUTHORS.md file at the
+# top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -36,6 +36,7 @@ use Sympa::DatabaseManager;
 use Sympa::List;
 use Sympa::Log;
 use Sympa::Regexps;
+use Sympa::Spool;
 use Sympa::Spool::Archive;
 use Sympa::Spool::Auth;
 use Sympa::Spool::Automatic;
@@ -44,6 +45,7 @@ use Sympa::Spool::Digest::Collection;
 use Sympa::Spool::Held;
 use Sympa::Spool::Incoming;
 use Sympa::Spool::Moderation;
+use Sympa::Task;
 use Sympa::Tools::File;
 
 use base qw(Sympa::Request::Handler);
@@ -221,8 +223,9 @@ sub _move {
     my $aliases = Sympa::Aliases->new(
         Conf::get_robot_conf($current_list->{'domain'}, 'alias_manager'));
     $aliases->del($current_list) if $aliases;
-    $current_list->_save_list_members_file(
-        $current_list->{'dir'} . '/subscribers.closed.dump');
+    $current_list->dump_users('member');
+    $current_list->dump_users('owner');
+    $current_list->dump_users('editor');
 
     # Set list status to pending if creation list is moderated.
     # Save config file for the new() later to reload it.
@@ -277,7 +280,7 @@ sub _move {
             sprintf('%s@%s', $listname, $robot_id),
             $current_list->get_id
         )
-        ) {
+    ) {
         $log->syslog('err',
             'Unable to rename list %s to %s@%s in the database',
             $current_list, $listname, $robot_id);
@@ -303,7 +306,7 @@ sub _move {
             $listname,               $robot_id,
             $current_list->{'name'}, $current_list->{'domain'}
         )
-        ) {
+    ) {
         $log->syslog('err',
             'Unable to transfer stats from list %s to list %s@%s',
             $current_list, $listname, $robot_id);
@@ -315,7 +318,7 @@ sub _move {
         qw(Sympa::Spool::Automatic Sympa::Spool::Bounce Sympa::Spool::Incoming
         Sympa::Spool::Auth Sympa::Spool::Held Sympa::Spool::Moderation
         Sympa::Spool::Archive Sympa::Spool::Digest::Collection)
-        ) {
+    ) {
         my $spool = $spool_class->new(context => $current_list);
         next unless $spool;
 
@@ -324,8 +327,8 @@ sub _move {
             last unless $handle;
             next
                 unless $message
-                    and ref $message->{context} eq 'Sympa::List'
-                    and $message->{context}->get_id eq $current_list->get_id;
+                and ref $message->{context} eq 'Sympa::List'
+                and $message->{context}->get_id eq $current_list->get_id;
 
             # Remove old HTML view if any (For moderation spool).
             $spool->html_remove($message) if $spool->can('html_remove');
@@ -349,16 +352,15 @@ sub _move {
     # Continue even if there are some troubles.
     #FIXME: Refactor to use Sympa::Spool subclass.
     $queue = $Conf::Conf{'queuetask'};
-    unless (opendir $dh, $queue) {
-        $log->syslog('err', 'Unable to open task spool %s: %m', $queue);
-    } else {
+    if (Sympa::Task::list_tasks($queue, $current_list->get_id)) {
         my $current_list_id = $current_list->get_id;
         my $new_list_id     = $fake_list->get_id;
 
-        foreach my $file (sort readdir $dh) {
+        foreach my $task (Sympa::Task::get_tasks_by_list($current_list_id)) {
+            my $file = $task->{'filename'};
             next
                 unless $file =~
-                    /^(\d+)\.(\w*)\.(\w+)\.([^\s\@]+)(?:\@([\w\.\-]+))?$/;
+                /^(\d+)\.(\w*)\.(\w+)\.([^\s\@]+)(?:\@([\w\.\-]+))?$/;
             my ($date, $label, $model, $listname, $domain) =
                 ($1, $2, $3, $4, $5);
             $domain ||= $Conf::Conf{'domain'};
@@ -372,8 +374,6 @@ sub _move {
                     $queue, $file, $newfile);
             }
         }
-
-        close $dh;
     }
 
     # Rename files in topic spool.
@@ -403,14 +403,14 @@ sub _move {
 
     # Rename files in outgoing spool.
     # Continue even if there are some troubles.
-    my $spool = Sympa::Bulk->new;
+    my $spool = Sympa::Bulk->new(context => $current_list);
     while (1) {
         my ($message, $handle) = $spool->next(no_filter => 1);
         last unless $handle;
         next
             unless $message
-                and ref $message->{context} eq 'Sympa::List'
-                and $message->{context}->get_id eq $current_list->get_id;
+            and ref $message->{context} eq 'Sympa::List'
+            and $message->{context}->get_id eq $current_list->get_id;
 
         my $pct_directory =
             $spool->{pct_directory} . '/' . $handle->basename(1);
@@ -476,7 +476,7 @@ sub _move {
             $listname,               $robot_id,
             $current_list->{'name'}, $current_list->{'domain'}
         )
-        ) {
+    ) {
         $log->syslog(
             'err',
             'Unable to transfer tracking information from list %s to list %s@%s',
@@ -523,6 +523,11 @@ sub _copy {
         $self->add_stash($request, 'intern');
         return undef;
     }
+
+    # Dump permanent/transitional owners and moderators (Not subscribers).
+    $current_list->dump_users('owner');
+    $current_list->dump_users('editor');
+
     chmod 0775, $new_dir;
     foreach my $subdir ('etc', 'web_tt2', 'mail_tt2', 'data_sources') {
         if (-d $new_dir . '/' . $subdir) {
@@ -531,7 +536,7 @@ sub _copy {
                     $current_list->{'dir'} . '/' . $subdir,
                     $new_dir . '/' . $subdir
                 )
-                ) {
+            ) {
                 $log->syslog(
                     'err',
                     'Failed to copy_directory %s: %m',
@@ -543,13 +548,13 @@ sub _copy {
         }
     }
     # copy mandatory files
-    foreach my $file ('config') {
+    foreach my $file ('config', 'owner.dump', 'editor.dump') {
         unless (
             File::Copy::copy(
                 $current_list->{'dir'} . '/' . $file,
                 $new_dir . '/' . $file
             )
-            ) {
+        ) {
             $log->syslog(
                 'err',
                 'Failed to copy %s: %m',
@@ -568,7 +573,7 @@ sub _copy {
                     $current_list->{'dir'} . '/' . $file,
                     $new_dir . '/' . $file
                 )
-                ) {
+            ) {
                 $log->syslog(
                     'err',
                     'Failed to copy %s: %m',
@@ -583,7 +588,7 @@ sub _copy {
     my $new_list;
     # Now switch List object to new list, update some values.
     unless ($new_list =
-        Sympa::List->new($listname, $robot_id, {'reload_config' => 1})) {
+        Sympa::List->new($listname, $robot_id, {skip_sync_admin => 1})) {
         $log->syslog('info', 'Unable to load %s while renamming', $listname);
         $self->add_stash($request, 'intern');
         return undef;
@@ -599,6 +604,10 @@ sub _copy {
     _modify_custom_subject($request, $new_list);
     $new_list->save_config($sender);
 
+    # Store permanent/transitional owners and moderators (Not subscribers).
+    $new_list->restore_users('owner');
+    $new_list->restore_users('editor');
+
     return 1;
 }
 
