@@ -33,13 +33,13 @@ package Sympa::Template;
 use strict;
 use warnings;
 use CGI::Util;
+use Encode qw();
 use English qw(-no_match_vars);
 use MIME::EncWords;
 use Template;
 
 use Sympa;
 use Conf;
-use Sympa::Constants;
 use Sympa::HTMLDecorator;
 use Sympa::Language;
 use Sympa::ListOpt;
@@ -168,9 +168,10 @@ sub locdatetime {
 
     if (defined $arg and $arg =~ /\A-?\d+\z/) {
         return sub { $language->gettext_strftime($_[0], localtime $arg); };
-    } elsif (defined $arg and $arg =~
+    } elsif (defined $arg
+        and $arg =~
         /\A(\d{4})\D(\d\d?)(?:\D(\d\d?)(?:\D(\d\d?)\D(\d\d?)(?:\D(\d\d?))?)?)?/
-        ) {
+    ) {
         my @arg =
             ($6 || 0, $5 || 0, $4 || 0, $3 || 1, $2 - 1, $1 - 1900, 0, 0, 0);
         return sub { $language->gettext_strftime($_[0], @arg); };
@@ -317,7 +318,7 @@ sub parse {
     }
 
     my $config = {
-        ABSOLUTE => ($self->{allow_absolute} ? 1 : 0),
+        ABSOLUTE     => ($self->{allow_absolute} ? 1 : 0),
         INCLUDE_PATH => [@include_path],
         PLUGIN_BASE  => 'Sympa::Template::Plugin',
         # PRE_CHOMP  => 1,
