@@ -46,6 +46,7 @@ use Sympa::LockedFile;
 use Sympa::Log;
 use Sympa::Message;
 use Sympa::Request;
+use Sympa::Scenario;
 use Sympa::Spool;
 use Sympa::Spool::Archive;
 use Sympa::Spool::Auth;
@@ -126,8 +127,8 @@ sub upgrade {
         return undef;
     }
 
-    ## Always update config.bin files while upgrading
-    Conf::delete_binaries();
+    #XXX# Always update config.bin files while upgrading
+    #XXXConf::delete_binaries();
 
     ## Always update config.bin files while upgrading
     ## This is especially useful for character encoding reasons
@@ -144,7 +145,8 @@ sub upgrade {
         }
     } else {
         # Prevent empty admin table (GH #71).
-        $log->syslog('notice', 'Skipping rebuild, no list config files found');
+        $log->syslog('notice',
+            'Skipping rebuild, no list config files found');
     }
 
     ## Migration to tt2
@@ -293,7 +295,7 @@ sub upgrade {
                             $table,
                             $sdm->quote($list->{'name'})
                         )
-                        ) {
+                    ) {
                         $log->syslog(
                             'err',
                             'Unable to fille the robot_admin and robot_subscriber fields in database for robot %s',
@@ -388,7 +390,7 @@ sub upgrade {
                         q{SELECT max(%s) FROM %s},
                         $field, $check{$field}
                     )
-                    ) {
+                ) {
                     $log->syslog('err', 'Unable to prepare SQL statement');
                     return undef;
                 }
@@ -608,7 +610,7 @@ sub upgrade {
             'mail_tt2', 'web_tt2',
             'scenari',  'create_list_templates',
             'families'
-            ) {
+        ) {
             if (-d $Conf::Conf{'etc'} . '/' . $type) {
                 push @directories,
                     [$Conf::Conf{'etc'} . '/' . $type, $Conf::Conf{'lang'}];
@@ -620,7 +622,7 @@ sub upgrade {
             Conf::get_wwsympa_conf(),
             $Conf::Conf{'etc'} . '/' . 'topics.conf',
             $Conf::Conf{'etc'} . '/' . 'auth.conf'
-            ) {
+        ) {
             if (-f $f) {
                 push @files, [$f, $Conf::Conf{'lang'}];
             }
@@ -632,7 +634,7 @@ sub upgrade {
                 'mail_tt2', 'web_tt2',
                 'scenari',  'create_list_templates',
                 'families'
-                ) {
+            ) {
                 if (-d $Conf::Conf{'etc'} . '/' . $vr . '/' . $type) {
                     push @directories,
                         [
@@ -660,7 +662,7 @@ sub upgrade {
                 'config',   'info',
                 'homepage', 'message.header',
                 'message.footer'
-                ) {
+            ) {
                 if (-f $list->{'dir'} . '/' . $f) {
                     push @files,
                         [$list->{'dir'} . '/' . $f, $list->{'admin'}{'lang'}];
@@ -746,30 +748,29 @@ sub upgrade {
                     $list->{'name'}
                 );
 
-                my @users = Sympa::List::_load_list_members_file(
-                    "$list->{'dir'}/subscribers");
+                # Load <list dir>/subscribers to the DB
+                if (-e $list->{'dir'} . '/subscribers'
+                    and rename $list->{'dir'} . '/subscribers',
+                    $list->{'dir'} . '/member.dump'
+                ) {
+                    $list->restore_users('member');
+
+                    my $total = $list->{'add_outcome'}{'added_members'};
+                    if (defined $list->{'add_outcome'}{'errors'}) {
+                        $log->syslog('err', 'Failed to add users: %s',
+                            $list->{'add_outcome'}{'errors'}{'error_message'}
+                        );
+                    }
+                    $log->syslog('notice',
+                        '%d subscribers have been loaded into the database',
+                        $total);
+                }
 
                 $list->{'admin'}{'user_data_source'} = 'include2';
 
-                ## Add users to the DB
-                $list->add_list_member(@users);
-                my $total = $list->{'add_outcome'}{'added_members'};
-                if (defined $list->{'add_outcome'}{'errors'}) {
-                    $log->syslog(
-                        'err',
-                        'Failed to add users: %s',
-                        $list->{'add_outcome'}{'errors'}{'error_message'}
-                    );
-                }
-
-                $log->syslog('notice',
-                    '%d subscribers have been loaded into the database',
-                    $total);
-
                 unless ($list->save_config('automatic')) {
                     $log->syslog('err',
-                        'Failed to save config file for list %s',
-                        $list->{'name'});
+                        'Failed to save config file for list %s', $list);
                 }
             } elsif ($list->{'admin'}{'user_data_source'} eq 'database') {
 
@@ -866,7 +867,7 @@ sub upgrade {
                         $sdm->quote($data->{'list_exclusion'}),
                         $sdm->quote($data->{'user_exclusion'})
                     )
-                    ) {
+                ) {
                     $log->syslog(
                         'err',
                         'Unable to update entry (%s, %s) in exclusions table (trying to add robot %s)',
@@ -918,7 +919,6 @@ sub upgrade {
             'custom_archiver'            => 'yes',
             'default_home'               => 'NO',
             'export_topics'              => 'yes',
-            'htmlarea_url'               => 'yes',
             'html_editor_file'           => 'NO',    # 6.2a
             'html_editor_init'           => 'NO',
             'ldap_force_canonical_email' => 'NO',
@@ -943,7 +943,8 @@ sub upgrade {
             'task_manager_pidfile' => 'No more used',
             'archived_pidfile'     => 'No more used',
             'bounced_pidfile'      => 'No more used',
-            'use_fast_cgi'         => 'No longer used', # 6.2.25b deprecated
+            'use_fast_cgi'         => 'No longer used',   # 6.2.25b deprecated
+            'htmlarea_url'         => 'No longer used',   # 6.2.36 deprecated
         );
 
         ## Set language of new file content
@@ -1437,7 +1438,7 @@ sub upgrade {
                   SET number_messages_subscriber = 0
                   WHERE number_messages_subscriber IS NULL}
             )
-            ) {
+        ) {
             $log->syslog('err',
                 'Can\'t update number_messages_subscriber field of subscriber_table.  You must update it manually.'
             );
@@ -1507,7 +1508,7 @@ sub upgrade {
                     qr/\A\.remove\.([^\s\@]+)(?:\@([\w\.\-]+))?\.(\d\d\d\d\-\d\d)\.(\d+)\z/,
                     [qw(localpart domainpart arc date)]
                 )
-                ) {
+            ) {
                 my $arc  = $metadata->{arc};
                 my $date = $metadata->{date};
                 my $list = $metadata->{context};
@@ -1546,7 +1547,7 @@ sub upgrade {
                     qr/\A\.rebuild\.([^\s\@]+)(?:\@([\w\.\-]+))?\z/,
                     [qw(localpart domainpart)]
                 )
-                ) {
+            ) {
                 my $list = $metadata->{context};
                 next unless ref $list eq 'Sympa::List';
 
@@ -1592,7 +1593,7 @@ sub upgrade {
                         qr/\A([^\s\@]+)\@([\w\.\-]+)\.(\d+)\.(\d+)\z/,
                         [qw(localpart domainpart date)]
                     )
-                    ) {
+                ) {
                     my $list = $metadata->{context};
                     next unless ref $list eq 'Sympa::List';
 
@@ -1775,6 +1776,43 @@ sub upgrade {
         );
     }
 
+    # Upgrade dump files for list users.
+    if (lower_version($previous_version, '6.2.33b.1')) {
+        $log->syslog('notice', 'Upgrading user dumps of closed lists.');
+        # Upgrading user dumps of closed lists.
+        my $lists =
+            Sympa::List::get_lists('*',
+            filter => [status => 'closed|family_closed']);
+        foreach my $list (@{$lists || []}) {
+            my $dir = $list->{'dir'};
+
+            if (-e $dir . '/subscribers.closed.dump') {
+                unlink $dir . '/member.dump.old';
+                rename $dir . '/member.dump', $dir . '/member.dump.old';
+                rename $dir . '/subscribers.closed.dump',
+                    $dir . '/member.dump';
+            }
+
+            my $fh;
+            next unless open $fh, '<', $dir . '/config';
+            my $config = do { local $RS; <$fh> };
+            close $fh;
+            # Write out initial permanent owners/editors in <role>.dump files.
+            $config =~ s/(\A|\n)[\t ]+(?=\n)/$1/g;    # normalize empty lines
+            open my $ifh, '<', \$config;              # open "in memory" file
+            my @config = do { local $RS = ''; <$ifh> };
+            close $ifh;
+            foreach my $role (qw(owner editor)) {
+                my $file = $dir . '/' . $role . '.dump';
+                if (!-e $file and open my $ofh, '>', $file) {
+                    my $admins = join '', grep {/\A\s*$role\b/} @config;
+                    print $ofh $admins;
+                    close $ofh;
+                }
+            }
+        }
+    }
+
     # GH Issue #240: PostgreSQL: Unable to edit owners/subscribers.
     if (lower_version($previous_version, '6.2.30')) {
         my $sdm = Sympa::DatabaseManager->instance;
@@ -1795,18 +1833,31 @@ sub upgrade {
         }
     }
 
-    # GH Issue #43: Preliminary notice on abolishment of "host" list parameter.
-    if (lower_version($previous_version, '6.2.32')) {
-        my $all_lists = Sympa::List::get_lists('*');
-        foreach my $list (@{$all_lists || []}) {
-            if (    $list->{'admin'}{'host'}
-                and $list->{'admin'}{'host'} ne $list->{'domain'}) {
-                $log->syslog(
-                    'notice',
-                    'NOTICE: %s: "host" parameter will be deprecated on Sympa 6.2.32. Please check list configuration and aliases',
-                    $list
-                );
+    # GH #330: wwsympa_url would be optional. http://domain/sympa is
+    # assigned to robot.conf for compatibility.
+    if (lower_version($previous_version, '6.2.33b.2')) {
+        my @robot_ids = Sympa::List::get_robots();
+        foreach my $robot_id (@robot_ids) {
+            next if $robot_id eq $Conf::Conf{'domain'};    # Primary domain
+
+            my $config_file = sprintf '%s/%s/robot.conf', $Conf::Conf{'etc'},
+                $robot_id;
+
+            my $ifh;
+            next unless open $ifh, '<', $config_file;
+            my ($parameter) = grep {/\Awwsympa_url\s+\S+/} <$ifh>;
+            close $ifh;
+            next if $parameter;
+
+            $log->syslog('info', 'Updating wwsympa_url for %s', $robot_id);
+            my $ofh;
+            unless (open $ofh, '>>', $config_file) {
+                $log->syslog('err', 'Cannot write to %s: %m', $config_file);
+                next;
             }
+            printf $ofh "\n\n# Added by upgrade from %s\n", $previous_version;
+            printf $ofh "wwsympa_url\thttp://%s/sympa\n",   $robot_id;
+            close $ofh;
         }
     }
 
@@ -1917,7 +1968,7 @@ sub to_utf8 {
                 group => Sympa::Constants::GROUP,
                 mode  => 0644,
             )
-            ) {
+        ) {
             $log->syslog('err', 'Unable to set rights on %s',
                 $Conf::Conf{'db_name'});
             next;
@@ -1990,7 +2041,7 @@ sub fix_colors {
                     'DELETE FROM conf_table WHERE label_conf like %s',
                     $sdm->quote($name)
                 )
-                ) {
+            ) {
                 $log->syslog('err',
                     'Cannot clean color parameters from database.');
             }
@@ -2087,7 +2138,7 @@ sub _get_canonical_read_date {
     } elsif ($sdm->isa('Sympa::DatabaseDriver::Sybase')) {
         return sprintf 'datediff(second, \'01/01/1970\',%s)', $target;
     } else {
-	# Unknown driver
+        # Unknown driver
         return $target;
     }
 }
@@ -2112,7 +2163,7 @@ sub _get_cacnonical_write_date {
     } elsif ($sdm->isa('Sympa::DatabaseDriver::Sybase')) {
         return sprintf 'dateadd(second,%s,\'01/01/1970\')', $target;
     } else {
-	# Unknown driver
+        # Unknown driver
         return $target;
     }
 }
